@@ -7,19 +7,19 @@ knitr::opts_chunk$set(
 ## ----setup--------------------------------------------------------------------
 library(replicateBE) # attach the library
 
-## ---- echo=FALSE--------------------------------------------------------------
-pub <- packageDate("replicateBE", date.fields = "Date/Publication")
+## ---- echo = FALSE------------------------------------------------------------
 txt <- paste0("Version ", packageVersion("replicateBE"), " built ",
          packageDate("replicateBE", date.fields = "Built"),
          " with R ", substr(packageDescription("replicateBE", fields = "Built"), 3, 7))
-if (is.na(pub)) {
+if (grepl("900",  as.character(packageVersion("replicateBE")))) {
   txt <- paste(txt, "\n(development version not on CRAN).")
 } else {
-  txt <- paste0(txt, "\n(stable release on CRAN ", pub, ").")
+  txt <- paste0(txt, "\n(stable release on CRAN ",
+           packageDate("replicateBE", date.fields = "Date/Publication"), ").")
 }
 cat(txt)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval = FALSE-------------------------------------------------------------
 #  modA <- lm(log(PK) ~ sequence + subject%in%sequence + period + treatment,
 #                       data = data)
 
@@ -44,31 +44,65 @@ cat(txt)
 #                        data = data[data$treatment = "R", ])
 
 ## ----expl1--------------------------------------------------------------------
-# Estimate sample sizes of full replicate designs (theta0 0.90, target
-# power 0.80) and CI of the CV with library PowerTOST
-CV <- 0.30
-n4 <- PowerTOST::sampleN.scABEL(CV = CV, design = "2x2x4", details = FALSE,
-                                print = FALSE)[["Sample size"]] # 4-period
-n3 <- PowerTOST::sampleN.scABEL(CV = CV, design = "2x2x3", details = FALSE,
-                                print = FALSE)[["Sample size"]] # 3-period
-# 95% CI of CVs in %
-round(100*PowerTOST::CVCL(CV = CV, df = 3*n4-4, "2-sided"), 2) # 4-period
-round(100*PowerTOST::CVCL(CV = CV, df = 2*n3-3, "2-sided"), 2) # 3-period
-# As above but assume that only 12 subjects remain in each sequence
-round(100*PowerTOST::CVCL(CV = CV, df = 3*24-4, "2-sided"), 2) # 4-period
-round(100*PowerTOST::CVCL(CV = CV, df = 2*24-3, "2-sided"), 2) # 3-period
+# Estimate sample sizes of full replicate designs (theta0 0.90,
+# target power 0.80) and CI of the CV with library PowerTOST
+CV     <- 0.30
+design <- c("2x2x4", "2x2x3") # 4- and 3-period full replicate designs
+res    <- data.frame(design = rep(design, 2), n = c(rep(NA, 2), rep(12, 2)),
+                     df = NA, CV = CV, lower = NA, upper = NA)
+# 95% confidence interval of the CV
+for (i in 1:nrow(res)) {
+  if (is.na(res$n[i])) {
+    res$n[i] <- PowerTOST::sampleN.scABEL(CV = CV,
+                                          design = res$design[i],
+                                          details = FALSE,
+                                          print = FALSE)[["Sample size"]]
+  }
+  if (i > 2 ) {
+    n.1 <- res$n[i-2] / 2 # no dropouts in one sequence
+    n.2 <- 12             # only 12 eligible subjects in the other
+    res$n[i] <- n.1 + n.2
+  }
+  if (res$design[i] == "2x2x4") {
+    res$df[i] <- 3 * res$n[i] - 4
+  } else {
+    res$df[i] <- 2 * res$n[i] - 3
+  }
+  res[i, 5:6] <- round(PowerTOST::CVCL(CV = CV,
+                                       df = res$df[i],
+                                       side = "2-sided",
+                                       alpha = 0.05), 3)
+}
+print(res, row.names = FALSE)
+# Rows 1-2: Sample sizes for target power
+# Rows 3-4: Only 12 eligible subjects in one sequence
+
+## ----typeIII------------------------------------------------------------------
+method.A(data = rds01, print = FALSE, verbose=TRUE)
 
 ## ----expl2--------------------------------------------------------------------
 # Calculate limits with library PowerTOST
-CV <- c(30, 40, 49.6, 50, 50.4)
-df <- data.frame(CV = CV, L = NA, U = NA, cap = "",
+CV <- c(30, 50, 57.382)
+df <- data.frame(CV = CV,
+                 reg1 = "EMA", L1 = NA, U1 = NA, cap1 = "",
+                 reg2 = "HC",  L2 = NA, U2 = NA, cap2 = "",
+                 reg3 = "GCC", L3 = NA, U3 = NA, cap3 = "",
                  stringsAsFactors = FALSE)
 for (i in seq_along(CV)) {
-  df[i, 2:3] <- sprintf("%.8f", PowerTOST::scABEL(CV[i]/100)*100)
+  df[i, 3:4]   <- sprintf("%.3f",
+                          PowerTOST::scABEL(CV[i]/100,
+                                            regulator = df$reg1[i])*100)
+  df[i, 7:8]   <- sprintf("%.1f",
+                          PowerTOST::scABEL(CV[i]/100,
+                                            regulator = df$reg2[i])*100)
+  df[i, 11:12] <- sprintf("%.3f",
+                          PowerTOST::scABEL(CV[i]/100,
+                                            regulator = df$reg3[i])*100)
 }
-df$cap[df$CV <= 30] <- "lower"
-df$cap[df$CV >= 50] <- "upper"
-names(df)[1:3] <- c("CV(%)", "L(%)", "U(%)")
+df$cap3[df$CV <= 30] <- df$cap2[df$CV <= 30] <- df$cap1[df$CV <= 30] <- "lower"
+df$cap1[df$CV >= 50 & df$reg1 == "EMA"]    <- "upper"
+df$cap2[df$CV >= 57.382 & df$reg2 == "HC"] <- "upper"
+names(df) <- c("CV(%)", rep(c("reg", "L(%)", "U(%)", "cap"), 3))
 print(df, row.names = FALSE)
 
 ## ----expl3--------------------------------------------------------------------
@@ -97,11 +131,11 @@ B1 <- method.B(print = FALSE, details = TRUE, data = rds14, option = 1)
 B2 <- method.B(print = FALSE, details = TRUE, data = rds14) # apply default option
 B3 <- method.B(print = FALSE, details = TRUE, data = rds14, option = 3)
 # Rounding of CI according to the GL
-A[15:19]  <- round(A[15:19],  2) # all effects fixed
-B1[15:19] <- round(B1[15:19], 2) # Satterthwaite's df
-B2[15:19] <- round(B2[15:19], 2) # df acc. to Q&A
-B3[15:19] <- round(B3[15:19], 2) # Kenward-Roger df
-cs <- c(2, 10, 15:23)
+A[17:21]  <- round(A[17:21],  2) # all effects fixed
+B1[17:21] <- round(B1[17:21], 2) # Satterthwaite's df
+B2[17:21] <- round(B2[17:21], 2) # df acc. to Q&A
+B3[17:21] <- round(B3[17:21], 2) # Kenward-Roger df
+cs <- c(2, 10, 17:25)
 df <- rbind(A[cs], B1[cs], B2[cs], B3[cs])
 names(df)[c(1, 3:6, 11)] <- c("Meth.", "L(%)", "U(%)",
                               "CL.lo(%)", "CL.hi(%)", "hw")
@@ -124,7 +158,7 @@ q[c(2, 4, 6:8), 4] <- c("SAS, Stata", "SciPy", "Phoenix, Minitab, SPSS",
                         "R, S, MATLAB, Octave, Excel", "Maple")
 print(as.data.frame(q))
 
-## ---- sessioninfo-------------------------------------------------------------
-options(width = 80)
+## ---- sessioninfo----------------------------------------
+options(width = 59)
 devtools::session_info()
 
